import { RequestType, RequestHandler } from 'vscode-jsonrpc';
import { Location, SymbolKind, Range } from 'vscode-languageserver-types';
import * as lsp from 'vscode-languageserver';
export interface CallHierarchyClientCapabilities {
    /**
     * The text document client capabilities
     */
    textDocument?: {
        /**
         * Capabilities specific to the `textDocument/callHierarchy`
         */
        callHierarchy?: {
            /**
             * Whether implementation supports dynamic registration. If this is set to `true`
             * the client supports the new `(TextDocumentRegistrationOptions & StaticRegistrationOptions)`
             * return value for the corresponding server capability as well.
             */
            dynamicRegistration?: boolean;
        };
    };
}
export interface CallHierarchyServerCapabilities {
    /**
     * The server provides Call Hierarchy support.
     */
    callHierarchyProvider?: boolean | (lsp.TextDocumentRegistrationOptions & lsp.StaticRegistrationOptions);
}
/**
 * Request to request the call hierarchy at a given text document position.
 *
 * The request's parameter is of type [CallHierarchyParams](#CallHierarchyParams). The response
 * is of type [CallHierarchyItem](#CallHierarchyItem) or a Thenable that resolves to such.
 *
 * The optional request's parameter defines the maximum number of levels to [resolve](#CallHierarchyParams.resolve) by this request.
 * Unresolved items can be resolved in subsequent `callHierarchy/resolve` requests.
 */
export declare namespace CallHierarchyRequest {
    const type: RequestType<CallHierarchyParams, CallHierarchyItem, void, lsp.TextDocumentRegistrationOptions>;
    type HandlerSignature = RequestHandler<CallHierarchyParams, CallHierarchyItem | null, void>;
}
/**
 * Request to resolve a call hierarchy item.
 *
 * The request's parameter is of type [ResolveCallHierarchyItemParams](#ResolveCallHierarchyItemParams). The response
 * is of type [CallHierarchyItem](#CallHierarchyItem) or a Thenable that resolves to such.
 */
export declare namespace CallHierarchyResolveRequest {
    const type: RequestType<ResolveCallHierarchyItemParams, CallHierarchyItem, void, void>;
    type HandlerSignature = RequestHandler<ResolveCallHierarchyItemParams, CallHierarchyItem | null, void>;
}
/**
 * The parameters of a `textDocument/callHierarchy` request.
 */
export interface CallHierarchyParams extends lsp.TextDocumentPositionParams {
    /**
     * The number of levels to resolve.
     */
    resolve?: number;
    /**
     * Outgoing direction for callees.
     * The default is incoming for callers.
     */
    direction?: 'incoming' | 'outgoing';
}
/**
 * The parameters of a `callHierarchy/resolve` request.
 */
export interface ResolveCallHierarchyItemParams {
    /**
     * Unresolved item.
     */
    item: CallHierarchyItem;
    /**
     * The number of levels to resolve.
     */
    resolve: number;
    /**
     * Outgoing direction for callees.
     * The default is incoming for callers.
     */
    direction: 'incoming' | 'outgoing';
}
/**
 * The result of a `textDocument/callHierarchy` request.
 */
export interface CallHierarchyItem {
    /**
     * The name of the symbol targeted by the call hierarchy request.
     */
    name: string;
    /**
     * More detail for this symbol, e.g the signature of a function.
     */
    detail?: string;
    /**
     * The kind of this symbol.
     */
    kind: SymbolKind;
    /**
     * URI of the document containing the symbol.
     */
    uri: string;
    /**
     * The range enclosing this symbol not including leading/trailing whitespace but everything else
     * like comments. This information is typically used to determine if the the clients cursor is
     * inside the symbol to reveal in the symbol in the UI.
     */
    range: Range;
    /**
     * The range that should be selected and revealed when this symbol is being picked, e.g the name of a function.
     * Must be contained by the the `range`.
     */
    selectionRange: Range;
    /**
     * The actual location of the call.
     *
     * **Must be defined** in resolved callers/callees.
     */
    callLocation?: Location;
    /**
     * List of incoming calls.
     *
     * *Note*: The items is _unresolved_ if `callers` and `callees` is undefined.
     */
    callers?: CallHierarchyItem[];
    /**
     * List of outgoing calls.
     *
     * *Note*: The items is _unresolved_ if `callers` and `callees` is undefined.
     */
    callees?: CallHierarchyItem[];
    /**
     * Optional data to identify an item in a resolve request.
     */
    data?: any;
}
//# sourceMappingURL=lsp-protocol.callHierarchy.proposed.d.ts.map